#script to compare chironomid-based temperature reconstructions with simulated temperatures of the warmest month, here: for Asia, Fig 5a and c and  to compare the openess in landscape (Fig.3 and Fig.5b)
# the model data needed is provided in this archive: "MPI-ESM_25kto0k_twarm.nc (temperature of the warmest month) and "MPI-ESM_openess.nc" (openness of the landscape)
# The chironomid-based temperature (Tjuly) reconstructions have to be downloaded (see README.txt file)
# The reconstructed openess is provided in tables for each continent seperately ("
# needs furthermore a table with the coordinates of the records (defined in this script, "coordinates" )

library(ncdf4)
library(irr)

#read model data
##########################################################
# a.) temperature file:
tfile <- nc_open("MPI-ESM_25kto0k_twarm.nc")
tempam <- ncvar_get(tfile, "temp2")
latc <- ncvar_get(tfile, "lat")
lonc <- ncvar_get(tfile, "lon")
londf <- as.data.frame(as.matrix(lonc))
latdf <- as.data.frame(as.matrix(latc))

df <- as.data.frame(as.matrix(latc))

londf$V1[londf$V1 >= 181] <- (londf$V1[londf$V1 >= 181] - 360)

#################################
# b.) openess
mfor <- nc_open("MPI-ESM_openess.nc")
bio <- ncvar_get(mfor, "cover_fract")

###########################
#timeaxis in the simulation
t=seq(-24950,50,100)
####################
# define time steps for the interpolation of the time-series

time <- (c(0,500,1000,1500, 2000,2500, 3000,3500,4000,4500,5000,5500,6000,6500,7000,7500,8000,8500,9000,9500,10000,10500,11000,11500,12000,12500,13000))

############################################################################

# define data frames to bundle the reconstructions (sibdata) and the model results (sibmodel) of each site/grid-cell in which a site is located

sibdata <- as.data.frame(time)
sibmodel <- as.data.frame(t)

######## individual records
## d1 Berkut # 66.3N, 36.7
#############################
londiff <- as.matrix((londf-36.7)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-66.3)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser1 <- tempam[lo+1,la,]-273.15

da1 <- read.table("Berkut.Ilyashuk.2005.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE) # 66.3N, 36.7

sibdat1 <- da1[,2:5]
sibdat1$nor <- sibdat1$V3/max(sibdat1$V3)
sibdat1$ano <- sibdat1$V3-sibdat1$V3[1]
los <- loess(sibdat1$V3~sibdat1$V2)
sibdat1$smp <- predict(los)
df1 <- transform(time, y.pred = predict(los, time))

sibdata$Berkut <- df1$y.pred

################################
# ESM1 52N 101,1E

da2 <- read.table("ESM-1.Mackay.2012.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)

londiff <- as.matrix((londf-101.1)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-52)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser2 <- tempam[lo,la,]-273.15

sibdat2 <- da2[,2:5]
sibdat2$nor <- sibdat2$V3/max(sibdat2$V3)
sibdat2$ano <- sibdat2$V3-sibdat2$V3[1]
los <- loess(sibdat2$V3~sibdat2$V2)
sibdat2$smp <- predict(los)
df2 <- transform(time, y.pred = predict(los, time))

sibdata$ESM1 <- df2$y.pred

#############
# Kharinei 67.4N 62.8E
da3 <- read.table("Kharinei.Jones.2011.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)


londiff <- as.matrix((londf-62.8)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-67.4)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser3 <- tempam[lo,la,]-273.15

sibdat3 <- da3
sibdat3$nor <- sibdat3$V3/max(sibdat3$V3)
sibdat3$ano <- sibdat3$V3-sibdat3$V3[1]
los <- loess(sibdat3$V3~sibdat3$V2)
sibdat3$smp <- predict(los)
df3 <- transform(time, y.pred = predict(los, time))

sibdata$Kharinei <- df3$y.pred

#########
#Lifebuoy 59.1N 163.2E
da4 <- read.table("LifebuoyLake.Solivieva.2015.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)

londiff <- as.matrix((londf-163.2)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-59.1)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser4 <- tempam[lo-2,la,]-273.15

sibdat4 <- da4[,3:6]
sibdat4$nor <- sibdat4$V4/max(sibdat4$V4)
sibdat4$ano <- sibdat4$V4-sibdat4$V4[1]
los <- loess(sibdat4$V4~sibdat4$V3)
sibdat4$smp <- predict(los)
df4 <- transform(time, y.pred = predict(los, time))

sibdata$Lifebuoy <- df4$y.pred


#############
# Lyadhej  68.3N 65.8
da5 <- read.table("Lyadhej-To.Andreev.2005.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)

londiff <- as.matrix((londf-65.8)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-68.3)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser5 <- tempam[lo,la,]-273.15

sibdat5 <- da5
sibdat5$nor <- sibdat5$V2/max(sibdat5$V2)
sibdat5$ano <- sibdat5$V2-sibdat5$V2[1]
los <- loess(sibdat5$V2~sibdat5$V1)
sibdat5$smp <- predict(los)
df5 <- transform(time, y.pred = predict(los, time))

sibdata$Lyadhey <- df5$y.pred

################
# Nikolay 73.3N 124.2E
da6 <- read.table("NikolayLake.Andreev.2004.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)


londiff <- as.matrix((londf-124.2)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-73.3)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser6 <- tempam[lo,la,]-273.15

sibdat6 <- da6[,2:5]
sibdat6$nor <- sibdat6$V3/max(sibdat6$V3)
sibdat6$ano <- sibdat6$V3-sibdat6$V3[1]
los <- loess(sibdat6$V3~sibdat6$V2)
sibdat6$smp <- predict(los)
df6 <- transform(time, y.pred = predict(los, time))

sibdata$Nikolay <- df6$y.pred

##########################
#Pechora 59.3N 163.1E
da7 <- read.table("PechoraLake.Andren.2015.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)

londiff <- as.matrix((londf-163.1)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-59.3)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser7 <- tempam[lo-1,la,]-273.15

sibdat7 <- da7[,2:6]
sibdat7$nor <- sibdat7$V4/max(sibdat7$V4)
sibdat7$ano <- sibdat7$V4-sibdat7$V4[1]
los <- loess(sibdat7$V4~sibdat7$V3)
sibdat7$smp <- predict(los)
df7 <- transform(time, y.pred = predict(los, time))

sibdata$Pechora <- df7$y.pred

###################
#Tiancai 26.63 N 99.72E
da8 <- read.table("TiancaiLake.Zhang.2017.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)

londiff <- as.matrix((londf-99.72)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-26.63)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser8 <- tempam[lo,la,]-273.15

sibdat8 <- da8[,2:5]
sibdat8$nor <- sibdat8$V3/max(sibdat8$V3)
sibdat8$ano <- sibdat8$V3-sibdat8$V3[1]
los <- loess(sibdat8$V3~sibdat8$V2)
sibdat8$smp <- predict(los)
df8 <- transform(time, y.pred = predict(los, time))

sibdata$Tiancai <- df8$y.pred

##############
# Temje  62.05N 129.48E
da9 <- read.table("Temje.Nazarova.2013.paleo1measurement1.csv",sep = ",", quote = "", header=FALSE)

londiff <- as.matrix((londf-129.48)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-62.05)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser9 <- tempam[lo,la,]-273.15

sibdat9 <- na.omit(da9[,3:6])

sibdat9$nor <- sibdat9$V4/max(sibdat9$V4)
sibdat9$ano <- sibdat9$V4-sibdat9$V4[1]

los <- loess(sibdat9$V4~sibdat9$V3)
sibdat9$smp <- predict(los)
df9 <- transform(time, y.pred = predict(los, time))

sibdata$Temje <- df9$y.pred

############################################################################
# write outputtable for reconstructions, time-series

#write.table (sibdata, file="chiro_Siberia.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

################
# prepare a list with coordinates of the records (longitude,latitude)
coordinates <-  matrix(c(36.66,66.34,101.0591,52.0269,62.7507,67.3628,163.1524,59.1099,65.8,68.26,124.2,73.33,163.13,59.2933,99.72,26.63,129.48,62.05, ncol=2, byrow=TRUE)

y10000 <- coordinates
for (i in 1:8) {
y10000$tJuly[i] <- sibdata[21,i+1]
}

write.table (y10000, file="tjuly_sib_10000b2k.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

##

y8000 <- coordinates
for (i in 1:8) {
y8000$tJuly[i] <- sibdata[17,i+1]
}

write.table (y8000, file="tjuly_sib_8000b2k.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
####


y7000 <- coordinates
for (i in 1:8) {
y7000$tJuly[i] <- sibdata[15,i+1]
}

write.table (y7000, file="tjuly_sib_7000b2k.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
####


y6000 <- coordinates
for (i in 1:8) {
y6000$tJuly[i] <- sibdata[13,i+1]
}

write.table (y6000, file="tjuly_sib_6000b2k.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

#############

y4000 <- coordinates
for (i in 1:8) {
y4000$tJuly[i] <- sibdata[9,i+1]
}

write.table (y4000, file="tjuly_sib_4000b2k.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
###################

y2000 <- coordinates
for (i in 1:8) {
y2000$tJuly[i] <- sibdata[5,i+1]
}

write.table (y2000, file="tjuly_sib_2000b2k.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
###############

ypi <- coordinates
for (i in 1:8) {
ypi$tJuly[i] <- sibdata[1,i+1]
}

write.table (ypi, file="tjuly_sib_pi.txt", sep = "\t", row.names=FALSE, col.names=FALSE)


###############################################

###
# calculate anomalies of the time series to first timestep (0ka)  and calculate the mean over all time-series
###
sibano <- sibdata[1:27, -1] - sibdata[rep(2,27),-1]
sibano$mean <- rowMeans(sibano[,2:9], na.rm = TRUE)
sibano$time <- sibdata$time


##### prepare data frame for the model results
##########
##########
sibmodel <- as.data.frame(t)
sibmodel$Berkut <- tser1
sibmodel$ESM1 <- tser2 
sibmodel$Kharinei <- tser3 
sibmodel$Lifebuoy <- tser4 
sibmodel$Lyadhej <- tser5 
sibmodel$Nikolay <- tser6
sibmodel$Pechora <- tser7
sibmodel$Tiancai <- tser8
sibmodel$Temje <- tser9

### calculate anomalies and mean over all time-series for the model
#############
sibanom <- sibmodel[1:251, -1] - sibmodel[rep(246,251),-1]
sibanom$mean <- rowMeans(sibanom[,2:9], na.rm = TRUE)
sibanom$time <- sibmodel$t



##################################
###########################################
######## openess comparison
######################
# look for the openess at each grid-cell in which a chironomid-site is located

##########################
londf <- as.data.frame(as.matrix(lon))
latdf <- as.data.frame(as.matrix(lat))

londf$V1[londf$V1 >= 181] <- (londf$V1[londf$V1 >= 181] - 360)

londiff <- as.matrix((londf-36.66)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-66.34)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser1b <- bio[lo,la,]


londiff <- as.matrix((londf-101.0591)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-52.0269)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser2b <- bio[lo,la,]


londiff <- as.matrix((londf-62.7507)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-67.3628)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser3b <- bio[lo,la,]


londiff <- as.matrix((londf-163.1524)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-59.1099)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser4b <- bio[lo,la,]

londiff <- as.matrix((londf-65.8)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-68.26)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser5b <- bio[lo,la,]


londiff <- as.matrix((londf-124.2)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-73.33)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser6b <- bio[lo,la,]

londiff <- as.matrix((londf-163.13)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-59.2933)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser7b <- bio[lo,la,]


londiff <- as.matrix((londf-99.72)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-26.63)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser8b <- bio[lo,la,]

londiff <- as.matrix((londf-129.48)^2)             # finds the grid-cell that locates the site
latdiff <- as.matrix((latdf-62.05)^2)

lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
la <- which.min(latdiff)
tser9b <- bio[lo,la,]


sibmodelb <- as.data.frame(t)
sibmodelb$Berkut <- tser1b
sibmodelb$ESM1 <- tser2b 
sibmodelb$Kharinei <- tser3b 
sibmodelb$Lifebuoy <- tser4b
sibmodelb$Lyadhej <- tser5b 
sibmodelb$Nikolay <- tser6b
sibmodelb$Pechora <- tser7b
sibmodelb$Tiancai <- tser8b
sibmodelb$Temje <- tser9b
#############
# calculate the mean over all chironomid-grid-cells
###############

sibanomb <- sibmodelb[1:251, -1] - sibmodelb[rep(246,251),-1]
sibanomb$mean <- rowMeans(sibanomb[,2:9], na.rm = TRUE)
sibanomb$time <- sibmodel$t

########################






##########################################################################

mfor <- nc_open("JSBACH_pmt_opensub2.nc")
openmod <- ncvar_get(mfor, "cover_fract")
latc <- ncvar_get(mfor, "lat")
lonc <- ncvar_get(mfor, "lon")
londf <- as.data.frame(as.matrix(lonc))
latdf <- as.data.frame(as.matrix(latc))
londf$V1[londf$V1 >= 181] <- (londf$V1[londf$V1 >= 181] - 360)
t <- seq(-24750,-150,100)


#############################

maximum <- matrix(0,nrow=dim(lonc), ncol=dim(latc))


for (i in 1:dim(lonc)) {

for (j in 1:dim(latc)) {

p <- which.max(openmod[i,j,])

q <- sum(openmod[i,j,])
print(c(i,j,p,t[p]))

maximum[i,j] <- t[p]

if (openmod[i,j,240] == -99999) {
maximum[i,j] <- 100
}
}
}

# define dimensions
#tunits2 <- tunit
londim <- ncdim_def("lon","degrees_east",as.double(lonc)) 
latdim <- ncdim_def("lat","degrees_north",as.double(latc)) 

# define variables
fillvalue <- -9999
dlname <- "tree_cover_max"
m_def <- ncvar_def("tree_max","",list(londim,latdim),fillvalue,dlname,prec="single")

# create netCDF file and put arrays
ncfname <- "pmt_moc_openess_NH_newsub.nc"
ncout <- nc_create(ncfname,list(m_def),force_v4=T)

# put variables
ncvar_put(ncout,m_def,maximum)


# put additional attributes into dimension and data variables
ncatt_put(ncout,"lon","axis","X") #,verbose=FALSE) #,definemode=FALSE)
ncatt_put(ncout,"lat","axis","Y")

# close the file, writing data to disk
nc_close(ncout)



#########
data <- read.table("Asia_forratio.txt", header=TRUE) 
#data <- read.table("Europe_forratio.txt", header=TRUE)
#data <- read.table("Nam_forratio.txt", header=TRUE)
data$AgeBP

q <- as.data.frame(unique(data[c("Long", "Lat")]))
p <- nrow(q)
cont_rec <- data[1,]*-5

for (i in c(1:p)) {
    site  <- data[(data$Lat == q$Lat[i] & data$Long == q$Long[i]),]
    rownames(site) <- NULL
    tsteps <- site$Age[(site$Age>=2000 & site$Age<=12000)]
    
    
    if (length(tsteps)>=20) {
    print(i)
    print(tsteps)
cont_rec <- rbind(cont_rec,site)
}
}

cont_rec <- cont_rec[2:nrow(cont_rec),]
 rownames(cont_rec) <- NULL
cont_rec$bio <- cont_rec$openess
cont_rec$bio[cont_rec$bio > 1] <- 1
cont_rec$bio[cont_rec$bio < 1] <- 0
cont_rec$Age <- -cont_rec$Age
###########si############

s <- as.data.frame(unique(cont_rec[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$max <- 100
tmax$fore <- 100

for (i in c(1:nrow(s))) {
    site  <- cont_rec[(cont_rec$Lat == s$Lat[i] & cont_rec$Long == s$Long[i]),]
    maxtime <- which.max(site$opennorm)
    tmax$max[i] <- -site$Age[maxtime]
    tmax$fore[i] <- site$bio[maxtime]
    }
    

write.table (tmax[,1:3], file="tmax_Asia_cont_subnorm.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

#######################

time <- sort(unique(cont_rec$Age))
modelsitet <-  matrix(-1,ncol=6, nrow=1)

for (u in c(1:length(time))) {

    record <- cont_rec[cont_rec$Age == time[u],]
    modelsite <- as.data.frame(cbind(record$Long, record$Lat,record$Age,record$opennorm,record$bio,c(-99999)))   

for (s in c(1:length(t))) {

if (t[s] == time[u]-50) {
    openm <- openmod[,,s]
    print(t[s])
    print(time[u])

for (i in c(1:nrow(record))) {

    londiff <- as.matrix((londf-record$Long[i])^2)             # finds the grid-cell that locates the site
    latdiff <- as.matrix((latdf-record$Lat[i])^2)

    lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
    la <- which.min(latdiff)                     # latitudinal grid-box number of the site-locating grid-box

    modelsite$V6[i] <- openm[lo,la]
    }
    
    }

}
print(modelsite)
modelsitet <- rbind(modelsitet,modelsite)
    
}
##############################################
colnames(modelsitet) <- c("Long","Lat","Age","open_rec","rec_bio","open_mod")
s <- as.data.frame(unique(modelsitet[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$r_max <- 100
tmax$fore <- 100
tmax$m_max <- 100

for (i in c(1:nrow(s))) {
    site  <- modelsitet[(modelsitet$Lat == s$Lat[i] & modelsitet$Long == s$Long[i]),]
    maxtime <- which.max(site$open_rec)
    tmax$r_max[i] <- site$Age[maxtime]
    tmax$fore[i] <- site$rec_bio[maxtime]
    maxtimem <- which.max(site$open_mod)
    tmax$m_max[i] <- site$Age[maxtimem]
    }
    
tmax$diff <- tmax$m_max - tmax$r_max

write.table (tmax[2:nrow(tmax),1:3], file="tmax_Asia_contr_norm.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,5)], file="tmax_Asia_contm_norm.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,6)], file="tmax_Asia_cont_diff_norm.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

###
###########################
#mean plot
mean <- as.data.frame(time)
mean$rec <- -99
mean$mod <- -99
min <- as.data.frame(time)
min$rec <- -99
min$mod <- -99
max <- as.data.frame(time)
max$rec <- -99
max$mod <- -99


for (u in c(1:length(time))) {

    record <- modelsitet[modelsitet$Age == time[u],]
    record$open_mod[record$open_mod <= -1.5] <- NA
    record <- na.omit(record)
    mean$mod[u] <- mean(record$open_mod)
    mean$rec[u] <- mean(record$open_rec)
    min$mod[u] <- min(record$open_mod)
    min$rec[u] <- min(record$open_rec)
    max$mod[u] <- max(record$open_mod)
    max$rec[u] <- max(record$open_rec)
}


pdf("Siberia_mean_anomaly.pdf")

par(mfrow=c(3,1))
par(mar = c(0.3,6, 1, 8))

plot(sibanomb$t,-sibanomb$mean, type="l",col="darkgrey", lwd=2.5, xlab = "", ylab = "",xaxt="n", yaxt="n", ylim = c(0.4,-0.5), xlim = c(-13000,0), cex.lab=1.5)
title(ylab="openness", line=4, cex.lab=1.5)
ytick<-seq(-0.4,0.4, by=0.2)
xtick<-seq(-12000,0, by=2000)
abline(h=seq(-0.4,0.4,0.2), lty=3, col="darkgrey")
axis(side=2, at=ytick, las=1, cex.axis=1.5)
axis(side=1, at=xtick, labels=FALSE, las=1, cex.axis=1.5)

lines(mean$time,-mean$rec, type="l",col="green", lwd=2.5)
lines(mean$time,-mean$mod, type="l",col="darkgreen", lwd=2.5)

legend(-4600,-0.48, inset=.015, legend=c("MPI-ESM chironomid-sites", "MPI-ESM all pollen sites", "Pollen records"), col=c("darkgrey", "darkgreen","green"), lwd=3, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)


plot(-sibano$time, sibano$mean, type="l", col = "red", xlab = "Years BP", ylab = "T warm anomalies", pch = 19, ylim = c(-1,3.3), yaxt="n", lwd=2.5, cex.lab=1.5, cex = 1.5, cex.axis=1.5 )
ytick<-seq(-1, 3.0, by=1)
axis(side=2, at=ytick, las=1, cex.axis=1.5)
abline(h=seq(-1,3,0.5), lty=3, col="darkgrey")
#lines(sibanomb$t[1:250],2*sibanomb$mean[1:250], type="l",col="cyan", lwd=1.5)
for (i in c(1:9)) {
lines(-sibano$time,sibano[,i], type="p",col="grey", lwd=1.5)
}

lines(-sibano$time,sibano$mean, type="l",col="red", lwd=2.5)
lines(sibanom$t[1:250],sibanom$mean[1:250], type="l",col="black", lwd=2.5)


legend(-4600,3.2, inset=.015, legend=c("MPI-ESM chironomid-sites","chironomid records"), col=c("black", "red"), lwd=3, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)

dev.off()




pdf("Asia_mean_openess.pdf")
plot(mean$time[5:40],mean$rec[5:40], type = "l", col = "black", xlab = "Years BP", ylab = "openess", pch = 19, main = "Asia mean openess", ylim = c(-1, 1), yaxt="n", lwd=2.5, cex.lab=1.1, cex = 0.5, )
ytick<-seq(-1, 1, by=0.2)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(h=seq(-1,1,0.2), lty=3, col="darkgrey")
#abline(v=c(-25000,-11000), lty=3, col="darkgrey")

#polygon(x = c(mean$time,rev(mean$time)), y = c(max$rec,rev(max$rec)), col =  adjustcolor("red", alpha.f = 0.20), border=NA)

lines(mean$time,mean$mod, type="l",col="red", lwd=2.5)
lines(mean$time,max$rec, type="l",col="grey", lwd=2.5)

lines(mean$time,max$mod, type="l",col="orange", lwd=2.5)

dev.off()

##################################################################data <- read.t

#######################
