# script to compare the climate data with the model results and prepare Figure 1 and Supplement Fig.1
# the reconstructions and the TRACE21ka data have to be downloaded, the model data is provide in the sub folder eval_tsers, please see the supplmentary table for the references of the reconstructions
# we have also used the compilation of speleothem records by Shah et al. (https://doi.org/10.25921/edce-mr22) for Cave of the Bell record and Fort Stanton record 
# only the reconstructed pollen-based biome mean is provided.

#######################
##### read in data
####################
# global , SH, and NH mean vs. Shakun et al and Osman et al. 
###############
#
# time axis
t = seq(-24950,50,100)
tt = seq(-21995,35,10)
tos = seq(-100,-23900,200)
#######
shakun <- read.table("shakun.csv", header=TRUE)
tNH <- read.table("./eval_tsers/MPIESM_tser_NH_mean_T.txt", header=FALSE)
#
tosNH <-read.table("Osman_Sat_ymNH090.txt", header=FALSE)

glotra <- read.table("T_traceglo8980.txt", header=FALSE)
tNHtra <- read.table("traceNH090.txt", header=FALSE)

# averaging the Trace data in 100 year climatological means (resolution of downloaded dataset is 10 years)
#####
glotra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)
glotra100$V2[i] <- mean(glotra$V1[k:l])
glotra100$V1[i] <- tt[l-5]
}

tNHtra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)
tNHtra100$V2[i] <- mean(tNHtra$V1[k:l])
tNHtra100$V1[i] <- tt[l-5]
}

######################################
##### precip Cariaco
#########################
pNH <- read.table("./eval_tsers/MPIESM_tser_NH_mean_P.txt", header=FALSE)
pNHtra <- read.table("trace_P_ym080.txt", header=FALSE)


pNHtra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)
pNHtra100$V2[i] <- mean(pNHtra$V1[k:l])
pNHtra100$V1[i] <- tt[l-5]
}

# the cariacao record is slightly smoothed...
cariacoraw <- read.table("cariaco25k.csv", header=TRUE)
loess50 <- loess(cariacoraw$L ~ cariacoraw$age, data=cariacoraw, span=0.03) 
cariaco <- predict(loess50)


pCaritra <- read.table("P_cariaco_trace.txt", header=FALSE)
pCaritra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)
pCaritra100$V2[i] <- mean(pCaritra$V1[k:l])
pCaritra100$V1[i] <- tt[l-5]
}


#######################
# insolation and CO2
###########################
insolj <- read.table("orbit91.csv",header=TRUE)
t65 <- read.table("T65_Jul_zm.txt",header=FALSE)
t15 <- read.table("T15_Jul_zm.txt",header=FALSE)
t65$V2 <- t
t15$V2 <- t

insolj$radnor <- insolj$X65NJul/(max(insolj$X65NJul))

co2 <- read.table("GHG_orbit_forcing.txt", header=TRUE)

co2$co2nor <- co2$CO2.ppm./(max(co2$CO2.ppm.))
#################################################################
# read in mega-biomes
###############################
formod <- read.table("./eval_tsers/MPIESM_contmean_forest.txt", header=FALSE)
records <- read.table("./eval_tsers/NH30_rec_macro_biome_means.txt", header=TRUE)

###############
# regional overview
########################
#Europe
#########
# Greenland GISP
gisp <- read.table("Gisp2n.csv", header=TRUE)
green <- read.table("./eval_tsers/MPIESM_Greenland_T.txt", header=FALSE)

greentrace <- read.table("T_ym_Greenland_trace.txt",header=FALSE)
greentrace100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))

for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

greentrace100$V2[i] <- mean(greentrace$V1[k:l])
greentrace100$V1[i] <- tt[l-5]
}

# Greenland P
################
gispp <- read.table("gisp2_accum.csv", header=TRUE)
greenp <- read.table("./eval_tsers/MPIESM_Greenland_P.txt", header=FALSE)


greentraceP <- read.table("P_Green_trace.txt",header=FALSE)
greentraceP100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))

for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

greentraceP100$V2[i] <- mean(greentraceP$V1[k:l])
greentraceP100$V1[i] <- tt[l-5]
}


#################
#############
#speleothems
speleo <- read.table("speleothem-d18o-0-22knur.csv", header=TRUE)
####################

# Ammersee
ammersee <- read.table("ammersee.csv", header=TRUE)
ammermod <- read.table("./eval_tsers/MPIESM_Ammersee_T.txt", header=FALSE) 

ammertra <- read.table("T_ammersee_trace.txt", header=FALSE)
ammertra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))

for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

ammertra100$V2[i] <- mean(ammertra$V1[k:l])
ammertra100$V1[i] <- tt[l-5]
}
###
#Soreq
##########
soreq <- read.table("soreq2012d18o_nur.csv", header=TRUE)
sormod <- read.table("./eval_tsers/MPIESM_Soreq_P.txt", header=FALSE) 
sortra <- read.table("P_Soreq_trace.txt", header=FALSE)
sortra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))

for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

sortra100$V2[i] <- mean(sortra$V1[k:l])
sortra100$V1[i] <- tt[l-5]
}

loess50 <- loess(soreq$d18O ~ soreq$age, data=soreq, span=0.03)
soreqs <- predict(loess50)

###############################################################
# Asia
###

#######################
#Hani Bog
##############
hani <- read.table("Hani.Zheng.2017nur.csv",header=TRUE)

hanimo <- read.table("./eval_tsers/MPIESM_Hanibog_T.txt",header=FALSE)

hanitra <- read.table("T_Hani_trace.txt",header=FALSE)
hanitra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

hanitra100$V2[i] <- mean(hanitra$V1[k:l])
hanitra100$V1[i] <- tt[l-5]
}

###############################################################
# Qinghai
##################
qinghai <- read.table("Qinghai.Hou.2016nur.csv", header=TRUE)
qinmod <- read.table("./eval_tsers/MPIESM_Qinghai_JJA_T.txt", header=FALSE)

qintra <- read.table("T_Qinghai_trace.txt", header=FALSE)
qintra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))

for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

qintra100$V2[i] <- mean(qintra$V1[k:l])
qintra100$V1[i] <- tt[l-5]
}


####################
####################
# Dongge
###########
dongge <- read.table("dongge2005b_nur.csv", stringsAsFactors=F, na.strings="unknown",header=FALSE)
dongmod <- read.table("./eval_tsers/MPIESM_Dongge_P.txt",header=FALSE)
donggtra <- read.table("P_Dongge_trace.txt",header=FALSE)
donggtra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

donggtra100$V2[i] <- mean(donggtra$V1[k:l])
donggtra100$V1[i] <- tt[l-5]
}
##################################################

# Lianhua
#########
lian <- read.table("lianhua2018d18o_nur.csv", header=TRUE)
lianmod <- read.table("./eval_tsers/MPIESM_Lianhua_P.txt",header=FALSE)

liantra <- read.table("P_lianhua_trace.txt",header=FALSE)
liantra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

liantra100$V2[i] <- mean(liantra$V1[k:l])
liantra100$V1[i] <- tt[l-5]
}


################################################
#Namerica
############
# DempsterPeatlandPorter
#########################
porter <- read.table("DempsterPeatland.Porternur.csv", header=TRUE)
portm <- read.table("./eval_tsers/MPIESM_Dempster_JJA_T.txt", header=FALSE)
porttra <- read.table("T_Porter_trace.txt", header= FALSE)
porttra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

porttra100$V2[i] <- mean(porttra$V1[k:l])
porttra100$V1[i] <- tt[l-5]
}


# Leviathan
################
levi <- read.table("Leviathan.Lachniet.2014nur.csv",header=TRUE)
levimod <- read.table("./eval_tsers/MPIESM_Levianthan_T.txt",header=FALSE)
levitra <- read.table("T_levi_trace.txt",header=FALSE)
levitra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

levitra100$V2[i] <- mean(levitra$V1[k:l])
levitra100$V1[i] <- tt[l-5]
}

###############################
# Cave Bell
##############
cavebell <- read.table("./eval_tsers/MPIESM_CaveBell_P.txt",header=FALSE)

cavebelltra <- read.table("P_cavebell_trace.txt",header=FALSE)
cavebelltra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

cavebelltra100$V2[i] <- mean(cavebelltra$V1[k:l])
cavebelltra100$V1[i] <- tt[l-5]
}

#########
# Fort Stanton

stantmod <- read.table("./eval_tsers/MPIESM_FortStanton_P.txt",header=FALSE)

stanttra <- read.table("P_stanton_trace.txt",header=FALSE)
stanttra100 <- as.data.frame(matrix(nrow=220,ncol=2,-99))
for (i in c(1:220)) {
k=(i-1)*10+1
l=(i*10)

stanttra100$V2[i] <- mean(stanttra$V1[k:l])
stanttra100$V1[i] <- tt[l-5]
}





###################################################################
####################################################################

#plot
pdf("Fig1_clim_eval_new.pdf")
par(mar = c(0.1, 7, 0.5, 10))
par(mfrow=c(7,1))

plot(insolj$age[1:26]+50, (insolj$X65NJul[1:26]-insolj$X65NJul[1]), type = "l", col = "magenta", xlim=c(-21950,50), xlab = "", ylim = c(-20, 50),ylab = expression(~Delta~"July insol 65N [W/m²]"), main = "", pch = 19, yaxt="n", xaxt="n", lwd=2, cex.lab=1, cex = 0.5, )
rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
ytick<-seq(-50.0, 50.0, by=10)

axis(side=2, at=ytick, las=1, cex.axis=1.1)

abline(h=seq(-20,50,10), lty=3, col="darkgrey")
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
#lines(insolj$age[1:26], (insolj$X15NJul[1:26]-insolj$X15NJul[1]), lwd=2, lty=2,col="red")

par(new = TRUE)
plot(co2$Age.yrBP.[1000:3500]*-1,  (co2$CO2.ppm.[1000:3500]-co2$CO2.ppm[1016]), type = "l", axes = FALSE, bty = "n", xlab = "", ylab = "", ylim = c(-120,20), xlim = c(-21950,0), col="cyan3", lwd=2)
ytick<-seq(-120.0, 12.0, by=20)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1,  col.axis="black")
mtext(expression(~Delta~"CO2 [ppm]"), side=4, line=3, col="black", cex=0.7)
############

#par(new = FALSE)
#plot(t, glob$V1-mean(glob$V1[136:186]), type = "l", col = "black", xlab = "Years BP", ylim = c(-5.0, 2), xlim=c(-21950,50), ylab=expression(~Delta~"Global T [K]"), main = "", lty=1, pch = 19, yaxt="n", xaxt="n", lwd=2, cex.lab=1, cex = 0.5, )

#ytick<-seq(-5.0, 2.0, by=1)
#axis(side=2, at=ytick, las=1, cex.axis=1.1)
# abline(h=seq(-5,2,1), lty=3, col="darkgrey")
#abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
#lines(glotra100$V1, glotra100$V2-(mean(glotra100$V2[106:156])), lty=2, lwd=2, col="darkgrey")

#lines(-shakun$age*1000, shakun$glob, lwd=2, col="red")

#rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
#rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
#rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

#legend("topleft", inset=.015, legend=c("Friedrich", "MPI-ESM"), col=c("red", "black"), lwd=3, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)
#############

par(new = FALSE)
plot(t, tNH$V1-mean(tNH$V1[136:186]), type = "l", col = "black", xlab = "Years BP", ylim = c(-10.0, 2), xlim=c(-21950,50), ylab=expression(~Delta~"NH T [K]"), main = "", lty=1, pch = 19, yaxt="n", xaxt="n", lwd=2, cex.lab=1, cex = 0.5, )

ytick<-seq(-10, 2.0, by=2)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
 abline(h=seq(-10,2,2), lty=3, col="darkgrey")
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")

lines(-shakun$age*1000, shakun$NH, lwd=2, col="red")
lines(tos, tosNH$V1-(mean(tosNH$V1[33:58])), lty=2, lwd=2, col="orange")

lines(tNHtra100$V1, tNHtra100$V2-(mean(tNHtra100$V2[106:156])), lty=2, lwd=2, col="darkgrey")

rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")


#legend("topleft", inset=.015, legend=c("Friedrich", "MPI-ESM"), col=c("red", "black"), lwd=3, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)

#
par(new = FALSE)
plot(t, pNH$V1-mean(pNH$V1[136:186]), type = "l", col = "black", xlab = "Years BP", ylim = c(-250.0, 100), xlim=c(-21950,50), ylab=expression(~Delta~"NH P [mm/yr]"), main = "", lty=1, pch = 19, yaxt="n", xaxt="n", lwd=2, cex.lab=1, cex = 0.5, )

ytick<-seq(-250.0, 100.0, by=50)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
 abline(h=seq(-300,100,50), lty=3, col="darkgrey")
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")

lines(pNHtra100$V1, pNHtra100$V2-(mean(pNHtra100$V2[106:156])), lty=2, lwd=2, col="darkgrey")

rect(-23000,-300,-19000,160, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-300,-12890,160, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-300,-11600,160, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")


par(new = TRUE)
plot(-cariacoraw$age,  -(cariaco-mean(cariaco[538:34800])), type = "l", axes = FALSE, bty = "n", xlab = "", ylab = "", ylim = c(-50,20), xlim = c(-21950,0), col="blue", lty=2, lwd=2)
ytick<-seq(-50.0, 20.0, by=10)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1,  col.axis="black")
mtext(expression(~Delta~"total reflectance"), side=4, line=3, col="black", cex=0.7)

#############


par(new = FALSE)
plot(t, green$V1-green$V1[249], type = "l", col = "black", xlab = "Years BP", ylim = c(-25, 5), xlim=c(-21950,50), ylab=expression(~Delta~"Greenland T [K]"), main = "", lty=1, pch = 19, yaxt="n", xaxt="n", lwd=2, cex.lab=1, cex = 0.5, )

ytick<-seq(-25.0, 5.0, by=5)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
 abline(h=seq(-25,5,5), lty=3, col="darkgrey")
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")

lines(gisp$Age, gisp$T-gisp$T[10], lwd=2, col="red")
lines(greentrace100$V1, greentrace100$V2-greentrace100$V2[219], lty=2, lwd=2, col="darkgrey")

rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

#legend("topleft", inset=.015, legend=c("Friedrich", "MPI-ESM"), col=c("red", "black"), lwd=3, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)


############# greenland precip
par(new = FALSE)
plot(t, greenp$V1-greenp$V1[249], type = "l", col = "black", xlab = "Years BP", ylim = c(-200, 50), xlim=c(-21950,50), ylab=expression(~Delta~"Greenland P [mm/yr]"), main = "", lty=1, pch = 19, yaxt="n", xaxt="n", lwd=2, cex.lab=1, cex = 0.5, )

ytick<-seq(-200.0, 50.0, by=50)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
 abline(h=seq(-200,50,50), lty=3, col="darkgrey")
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")


lines(greentraceP100$V1, greentraceP100$V2-greentraceP100$V2[219], lty=2, lwd=2, col="darkgrey")

rect(-23000,-400,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-400,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-400,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

#legend("topleft", inset=.015, legend=c("Friedrich", "MPI-ESM"), col=c("red", "black"), lwd=3, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)

par(new = TRUE)
plot(-gispp$age*1000, (gispp$accum-gispp$accum[12]), type = "l", axes = FALSE, bty = "n", xlab = "", ylab = "", ylim = c(-0.4,0.1), xlim = c(-21950,0), col="blue", lwd=2)
ytick<-seq(-0.4, 0.1, by=0.1)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1,  col.axis="black")
mtext(expression(~Delta~"ice acc. per year"), side=4, line=3, col="black", cex=0.7)

#########
plot(t, formod$V1-formod$V1[250],type = "l", col = "darkgreen", xlab = "Years BP", ylim = c(-60, 15), xlim=c(-21950,50), ylab="forest coverage > 30°N [%]", main = "", lty=1, pch = 19, yaxt="n", lwd=2, cex.lab=1, cex = 0.5, )

ytick<-seq(-60.0, 15.0, by=15)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
 abline(h=seq(-60,15,15), lty=3, col="darkgrey")
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")

lines(-records$age*1000, records$forest-records$forest[1], lwd=2, col="green")


rect(-23000,-70,-19000,120, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-70,-12890,120, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-70,-11600,120, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

#legend("bottomright", inset=.015, legend=c("reconstructions", "MPI-ESM"), col=c("red", "black"), lwd=3, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)

dev.off()


#####################regional###############
############################################
pdf("Fig_supp1_clim_eval_reg_T_new.pdf")
par(mar = c(0.1, 7, 0.5, 10))
par(mfrow=c(7,1))

plot(ammersee$Age*-1,  (ammersee$d18O-ammersee$d18O[56]), type = "l", xlab = "years BP", ylab = "", ylim
 = c(-6, 1.4), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-6.0, 1.0, by=1)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
mtext(expression(~Delta~"Ammersee d18O "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, (ammermod$V2-ammermod$V2[249]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-30, 7),ylab = expression(~Delta~"Ammersee T [K]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )

ytick<-seq(-30.0, 5.0, by=5)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-30,5,5), lty=3, col="darkgrey")

rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(ammertra100$V1, ammertra100$V2-ammertra100$V2[219], lty=2, lwd=2.5, col="darkgrey")

##############

plot(hani$age*-1,  (hani$temperature-hani$temperature[2]), type = "l", ylab = expression(~Delta~"Hani Bog T"), xaxt="n",ylim = c(-15, 10), xlim = c(-21950,0), col="red", lwd=2.5)
ytick<-seq(-15, 10, by=5)
#axis(side=4, at = ytick, las=1, col="red", cex.axis=1.1)
abline(h=seq(-15,10,5), lty=3, col="darkgrey")
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")

lines(hanitra100$V1, hanitra100$V2-hanitra100$V2[219], lty=2, lwd=2.5, col="darkgrey")
lines(t, hanimo$V1-hanimo$V1[249], lty=1, lwd=2.5, col="black")

rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")


#####

plot(qinghai$age*-1,  (qinghai$T-qinghai$T[2]), type = "l", xlab = "years BP", ylab = "", ylim
 = c(-10, 10.0), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-10.0, 10.0, by=5)
#axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
#mtext(expression(~Delta~"Qinghai TJuly "), side=4, line=3, col="black",cex=0.7)


par(new = TRUE)
plot(t, (qinmod$V1-qinmod$V1[249]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-10, 10),ylab = expression(~Delta~"Qinghai T [K]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )

ytick<-seq(-15.0, 5.0, by=5)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-15,5,5), lty=3, col="darkgrey")

rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")


lines(qintra100$V1, qintra100$V2-qintra100$V2[219], lty=2, lwd=2.5, col="darkgrey")

#########################################


#plot(mangshan$age*-1,  (mangshan$T-mangshan$T[6]), type = "l", xlab = "years BP", ylab = "", ylim  = c(-15, 5.0), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
#ytick<-seq(-15.0, 5.0, by=5)
#axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
#mtext(expression(~Delta~"Qinghai TJuly "), side=4, line=3, col="black",cex=0.7)

#par(new = TRUE)
#plot(t, (manmod$V1-manmod$V1[190]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-15, 5),ylab = expression(~Delta~"Mangshan T MJJAS [K]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )
#ytick<-seq(-15.0, 5.0, by=5)
#axis(side=2, at=ytick, las=1, cex.axis=1.1)
#abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
#abline(h=seq(-15,5,5), lty=3, col="darkgrey")

#rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
#rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
#rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

#lines(mantra100$V1, mantra100$V2-mantra100$V2[219], lty=2, lwd=2.5, col="darkgrey")

############################

plot(porter$age*-1,  (porter$T-porter$T[12]), type = "l", xlab="", ylab = "", ylim  = c(-9, 5.0), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-9.0, 5.0, by=3)
#axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
#mtext(expression(~Delta~"Qinghai TJuly "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, (portm$V1-portm$V1[249]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-9, 5),ylab = expression(~Delta~"Porter T JJAS [K]"), main = "", pch = 19, axes = FALSE, lwd=2.5,  xaxt="n", cex.lab=1, cex = 0.5, )
ytick<-seq(-9.0, 5.0, by=3)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-9,3,3), lty=3, col="darkgrey")

rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(porttra100$V1, porttra100$V2-porttra100$V2[219], lty=2, lwd=2.5, col="darkgrey")

####################################

plot(levi$age*-1, (levi$d18O-levi$d18O[4]), type = "l", xlab = "", ylab = "", ylim  = c(-9, 3.0), yaxt="n", xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-9.0, 3.0, by=3)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
mtext(expression(~Delta~"Leviathan d18O "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, (levimod$V1-levimod$V1[249]), type = "l", xlab="years BP",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-9, 3),ylab = expression(~Delta~"Leviathan T [K]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )
ytick<-seq(-9.0, 3.0, by=3)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-9,3,3), lty=3, col="darkgrey")

rect(-23000,-30,-19000,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-30,-12890,60, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-30,-11600,60, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(levitra100$V1, levitra100$V2-levitra100$V2[219], lty=2, lwd=2.5, col="darkgrey")

dev.off()

#################################################
#precip
##################
pdf("clim_eval_reg_p_new.pdf")
par(mar = c(0.1, 7, 0.5, 10)) # par(mar = c(0.1, 4, 0.5, 5))
par(mfrow=c(7,1))

plot(soreq$age*-1, -(soreqs-soreqs[234]), type = "l", xlab = "years BP", ylab = "", ylim  = c(-4, 6.0), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-4.0, 6.0, by=2)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
mtext(expression(~Delta~"Soreq d18O "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, 365*(sormod$V1-sormod$V1[190]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-40, 60),ylab = expression(~Delta~"Soreq P [mm/yr]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )
ytick<-seq(-40, 60, by=20)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-40,60,20), lty=3, col="darkgrey")

rect(-23000,-50,-19000,80, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-50,-12890,80, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-50,-11600,80, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(sortra100$V1, 365*(sortra100$V2-sortra100$V2[160]), lty=2, lwd=2.5, col="darkgrey")
##########################

plot(lian$age*-1000, -(lian$d18O-lian$d18O[332]), type = "l", xlab = "years BP", ylab = "", ylim  = c(-6, 3.0), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-6.0, 3.0, by=2)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
mtext(expression(~Delta~"Lianhua d18O "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, 365*(lianmod$V1-lianmod$V1[190]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-600, 300),ylab = expression(~Delta~"Liange P [mm/yr]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )
ytick<-seq(-600, 300, by=200)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-600,300,200), lty=3, col="darkgrey")

rect(-23000,-600,-19000,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-600,-12890,800, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-600,-11600,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(liantra100$V1, 365*(liantra100$V2-liantra100$V2[160]), lty=2, lwd=2.5, col="darkgrey")

###############################
##################
plot(dongge$V1*-1, -(dongge$V2-dongge$V2[350]), type = "l", xlab = "years BP", ylab = "", ylim  = c(-6, 4.0), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-6.0, 4.0, by=2)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
mtext(expression(~Delta~"Dongge d18O "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, 365*(dongmod$V1-dongmod$V1[190]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-600, 400),ylab = expression(~Delta~"Dongge P [mm/yr]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )
ytick<-seq(-600, 400, by=200)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-600,400,200), lty=3, col="darkgrey")

rect(-23000,-600,-19000,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-600,-12890,800, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-600,-11600,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(donggtra100$V1, 365*(donggtra100$V2-donggtra100$V2[160]), lty=2, lwd=2.5, col="darkgrey")


###############################################################################

# stanton 16
# cave of the bells 1
cave<- as.data.frame(cbind(-speleo$age_calBP[speleo$Index==1],speleo$d18OcarbPDB[speleo$Index==1]))
colnames(cave) <- c("V1","V2")
plot(cave$V1, (cave$V2-cave$V2[31]), type = "l", xlab = "years BP", ylab = "", ylim  = c(-4, 4.0), yaxt="n", xaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-4.0, 4.0, by=2)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
mtext(expression(~Delta~"Cave of the bell d18O "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, -365*(cavebell$V1-cavebell$V1[131]), type = "l", xlab="",col = "black",xaxt="n", xlim=c(-21950,50), ylim = c(-400, 400),ylab = expression(~Delta~"Cave of the bell P [mm/yr]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )
ytick<-seq(-400, 400, by=200)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-400,400,200), lty=3, col="darkgrey")

rect(-23000,-600,-19000,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-600,-12890,800, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-600,-11600,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(cavebelltra100$V1,(cavebelltra100$V2-cavebelltra100$V2[101]), lty=2, lwd=2.5, col="darkgrey")

#########
stanton<- as.data.frame(cbind(-speleo$age_calBP[speleo$Index==16],speleo$d18OcarbPDB[speleo$Index==16]))
colnames(stanton) <- c("V1","V2")
plot(stanton$V1, (stanton$V2-stanton$V2[8]), type = "l", xlab = "years BP", ylab = "", ylim  = c(-6.0, 8.0), yaxt="n",xlim=c(-21950,50), col="red", lwd=2.5)
ytick<-seq(-6.0, 8.0, by=2)
axis(side=4, at = ytick, las=1, col="black", cex.axis=1.1)
mtext(expression(~Delta~"Fort Stanton d18O "), side=4, line=3, col="black",cex=0.7)

par(new = TRUE)
plot(t, -365*(stantmod$V1-stantmod$V1[131]), type = "l", xlab="years BP",col = "black", xlim=c(-21950,50), ylim = c(-600, 800),ylab = expression(~Delta~"Stantdon P [mm/yr]"), main = "", pch = 19, axes = FALSE, lwd=2.5, cex.lab=1, cex = 0.5, )
ytick<-seq(-600, 800, by=200)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(v=seq(-25000,0,5000), lty=3, col="darkgrey")
abline(h=seq(-600,800,200), lty=3, col="darkgrey")

rect(-23000,-600,-19000,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")
rect(-14690,-600,-12890,800, col= rgb(0.7,0,0,alpha=0.1), border = "transparent")
rect(-12900,-600,-11600,800, col= rgb(0,0,0.7,alpha=0.1), border = "transparent")

lines(stanttra100$V1,365*(stanttra100$V2-stanttra100$V2[101]), lty=2, lwd=2.5, col="darkgrey")

#######################

