# script to calculate the records density, site-based means, agreement between model and reconstrucitions
# needed to plot Supp. Fig2, and Fig.4

#!/usr/bin/env Rscript
library(dplyr)


#reading data
total1 <- read.table("25krun_rec_mod_datatNH30.txt", header=FALSE)
colnames(total1) <- c("Longitude","Latitude","KaBP","biomREC","Mega_biome")

#total1$Mega_biome[total$Mega_biome < 0.8] <- NA
#####

####################
#removing problematic records

probrecs <- read.table("prob_records_0kRF.txt", header=FALSE)
colnames(probrecs) <- c("Longitude","Latitude","difference")

total <- anti_join(total1, probrecs, by = c("Longitude","Latitude"))

###############################
#calculating biome_means

time <- sort(unique(total$KaBP))

meanmodel <- as.data.frame(time)
meanrec <- as.data.frame(time)

for (k in c(1:length(time))) {

rec <- total[total$KaBP == time[k],]
meanmodel$forest[k]<- (sum(rec$Mega_biome[rec$Mega_biome == 1]))/nrow(rec)
meanmodel$grass[k]<- (sum(rec$Mega_biome[rec$Mega_biome == 2]))/(2*nrow(rec))
meanmodel$desert[k]<- (sum(rec$Mega_biome[rec$Mega_biome == 3]))/(3*nrow(rec))
meanmodel$tundra[k]<- (sum(rec$Mega_biome[rec$Mega_biome == 4]))/(4*nrow(rec))

meanrec$forest[k]<- (sum(rec$biomREC[rec$biomREC == 1]))/nrow(rec)
meanrec$grass[k]<- (sum(rec$biomREC[rec$biomREC == 2]))/(2*nrow(rec))
meanrec$desert[k]<- (sum(rec$biomREC[rec$biomREC == 3]))/(3*nrow(rec))
meanrec$tundra[k]<- (sum(rec$biomREC[rec$biomREC == 4]))/(4*nrow(rec))

} 

#number of records, mean forest change
###################################
#########

total$Mega_biome[total$Mega_biome > 1.5] <- 2
total$biomREC[total$biomREC > 1.5] <- 2
total<-na.omit(total)
#
######################################

time <- sort(unique(total$KaBP))
totmean <- as.data.frame(time)
totrec  <- as.data.frame(time)
nrec <- as.data.frame(time)
nrec$nr <- -10
#rownames() <- NULL
for (t in c(1:length(time))) {

rec <- total[total$KaBP == time[t],]
nrec$nr[t] <- nrow(rec)

totmean$mean[t]<- (sum(rec$Mega_biome[rec$Mega_biome == 1]))/nrow(rec)
totrec$mean[t]<- (sum(rec$biomREC[rec$biomREC == 1]))/nrow(rec)
}

-----------------------------------------------
#GC grouping 10° x 5° 
#######################
lons <- seq(-175.0, 175.0, by=10)
lats <- seq(32.5, 80, by=5)

time <- sort(unique(total$KaBP))

GCforest5 <- data.frame(matrix(0,nrow=360*length(time),ncol=4))
GCdens5 <- data.frame(matrix(0,nrow=360*length(time),ncol=4))

GCforestrec5 <- data.frame(matrix(0,nrow=360*length(time),ncol=4))

formean5 <- as.data.frame(time)
formean5$mean <- -1

formeanrec5 <- as.data.frame(time)
formeanrec5$mean <- -1


colnames(GCforest5) <- c("Longitude","Latitude","KaBP","forest")
colnames(GCforestrec5) <- c("Longitude","Latitude","KaBP","forest")
colnames(GCdens5) <- c("Longitude","Latitude","KaBP","nrec")


for (t in c(1:length(time))) {

       for (i in c(1:36)) {
              s=-180+(i-1)*10
	      		for (k in c(1:10)) {
    				    r=30+(k-1)*5

				    records <- total[(total$KaBP == time[t] & total$Latitude >= r & total$Latitude < (r+5) & total$Longitude >= s & total$Longitude < (s+10)),]
				   
				    GCdens5$Longitude[(t-1)*360+(i-1)*10+k] = (s+5)
				    GCdens5$Latitude[(t-1)*360+(i-1)*10+k] = (r+2.5)
				    GCdens5$nrec[(t-1)*360+(i-1)*10+k] = nrow(records)
				    GCdens5$KaBP[(t-1)*360+(i-1)*10+k] = time[t]

 				    GCforest5$Longitude[(t-1)*360+(i-1)*10+k] = (s+5)
				    GCforest5$Latitude[(t-1)*360+(i-1)*10+k] = (r+2.5)
				    GCforest5$forest[(t-1)*360+(i-1)*10+k] = (sum(records$Mega_biome[records$Mega_biome == 1]))/nrow(records)
				    GCforest5$KaBP[(t-1)*360+(i-1)*10+k] = time[t]

 				    GCforestrec5$Longitude[(t-1)*360+(i-1)*10+k] = (s+5)
				    GCforestrec5$Latitude[(t-1)*360+(i-1)*10+k] = (r+2.5)
				    GCforestrec5$forest[(t-1)*360+(i-1)*10+k] = (sum(records$biomREC[records$biomREC == 1]))/nrow(records)
				    GCforestrec5$KaBP[(t-1)*360+(i-1)*10+k] = time[t]



                       		     }
			}
				   formean5$mean[t] <- mean(na.omit(GCforest5$forest[GCforest5$KaBP == time[t]]))
				   formeanrec5$mean[t] <- mean(na.omit(GCforestrec5$forest[GCforestrec5$KaBP == time[t]]))				  
    			   }
			   

##########################################
####################################################
## fitting tsers GC-based
###############################
total_fitGC <- GCforestrec5
total_fitGC$model <- GCforest5$forest

total_fitGCNA <- na.omit(total_fitGC)

total_fitGCNA$fit <- 0

total_fitGCNA$fit <- total_fitGCNA$forest - total_fitGCNA$model

################
# grid-cell agreement
#-------------
sitesl <- unique(total_fitGCNA[c("Latitude","Longitude")])
sites <- sitesl[order(-sitesl$Latitude),]

agree <- matrix(ncol=9,nrow=(nrow(sites)))

for (s in c(1:nrow(sites))) {

    vec1 <- total_fitGCNA$fit[(total_fitGCNA$Latitude == sites$Latitude[s] & total_fitGCNA$Longitude == sites$Longitude[s])]
    agree[s,2] <- sites$Latitude[s]
    agree[s,1] <- sites$Longitude[s]
    agree[s,3] <- length(vec1)
    agree[s,4] <- sum(abs(vec1))/length(vec1)
    agree[s,5] <- 1-agree[s,4]
    agree[s,6] <- length(which(vec1 == 0))
    agree[s,7] <- length(which(abs(vec1) < 0.2))/length(vec1)
    agree[s,8] <- 1-agree[s,7]
    agree[s,9] <- sum(vec1)/length(vec1)
    } 


write.table (agree, file="22krunGC_agreement.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (agree[,c(1,2,7)], file="22krunGC_percent_tstep_agreement.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (agree[,c(1,2,4)], file="22krunGC_mean_difference.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (agree[,c(1,2,9)], file="22krunGC_mean_tot_difference.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (agree[,c(1,2,6)], file="22krunGC_tstep_agreement.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
################

tall <- unique(total_fitGCNA$KaBP)
fitsGC <- matrix(ncol=4,nrow=(length(tall)))

for (s in c(1:length(tall))) {

    vec <- total_fitGCNA$fit[(total_fitGCNA$KaBP == tall[s])]
        
    fitsGC[s,1] <- tall[s]
    fitsGC[s,2] <- length(vec[vec==0])/length(vec)
    fitsGC[s,4] <- length(vec)
    fitsGC[s,3] <- sum(abs(vec))/length(vec)
    }


forest11k <-total_fitGC[total_fitGC$KaBP==11.0,]

write.table (fitsGC[,c(1,2)], file="25krun_perfitsGC.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (fitsGC[,c(1,3)], file="25krun_absperf_GC.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (fitsGC[,c(1,4)], file="25krun_GCpertime.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (forest11k[,c(1,2,4)], file="25krun_GCforestfrac11krec.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (forest11k[,c(1,2,5)], file="25krun_GCforestfrac11mod.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

#######

pdf("25krun_biomes_GC5_fits.pdf")
par(mar = c(15, 4, 4, 6)+ 0.1)
plot(-fitsGC[,1]*1000,fitsGC[,2]*100, type = "l", col = "black", xlab = "Years BP", ylab = "agreement", pch = 19, main = "agreement (GC-based)", ylim = c(0.0, 100.0), yaxt="n", lwd=2.5, cex.lab=1.1, cex = 0.5, )
ytick<-seq(0.0, 100.0, by=20.0)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(h=seq(0,100,20), lty=3, col="darkgrey")

lines(-fitsGC[,1]*1000,fitsGC[,3]*100, type="l",lty=4,  col="red", lwd=2.5)


par(new=TRUE)
plot(-fitsGC[,1]*1000,fitsGC[,4], type = "l", col = "blue", lty=4, xlab = "", ylab = "", pch = 19, main = "agreement (GC-based)", ylim = c(0.0, 180.0), axes=FALSE, lwd=2.5, cex.lab=1.1, cex = 0.5, )
ytick<-seq(0.0, 180.0, by=50.0)
axis(side=4, at=ytick, las=1, col.axis="blue", cex.axis=1.1, col="blue")
mtext("number of grid-cells",side=4,col="blue",line=4)

legend("topleft", inset=.015, legend=c("perc. agreement","abs. difference(*100)","nr. grid-cells"), col=c("black", "red","blue"), lwd=3, lty=c(1,4,4),  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)
dev.off()


#################################################
pdf("25krun_biomes_GCsite_forest_5.pdf")
par(mar = c(15, 4, 4, 4))
plot(-formean5$time*1000,formean5$mean*100, type = "l", col = "black", xlab = "Years BP", ylab = "forest fraction >30°N [%] ", pch = 19, main = "GC-based vs. site-based", ylim = c(0.0, 100.0), yaxt="n", lwd=2.5, cex.lab=1.1, cex = 0.5, )
ytick<-seq(0.0, 100.0, by=20.0)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
 abline(h=seq(0,100,20), lty=3, col="darkgrey")


 #abline(v=c(-24.250, -14.550, -10.150,-0.350), lty=2, col="red")
#abline(v=c(-22, -12, -7,-0.35), lty=4, col="blue")

lines(-formeanrec5$time*1000,formeanrec5$mean*100, type="l", col="red", lwd=2.5)
lines(-formeanrec5$time*1000,totrec$mean*100, type="l",lty=4,  col="red", lwd=2.5)

lines(-formeanrec5$time*1000,totmean$mean*100, type="l",lty=4,  col="black", lwd=2.5)

#lines(-formeanrec5$time,formean5$mean*100, type="l", col="red", lwd=2.5)


legend("topleft", inset=.015, legend=c("MPI-ESM, GC-based", "Records, GC-based", "MPI-ESM, site-based", "Records, site-based"), col=c("black", "red", "black","red"), lwd=3, lty=c(1,1,4,4),  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)

dev.off()
#########################

#################################################
#############################################
# fitting tsers site-based
###############################
total_fit <- total
total_fit$fit <- 0

total_fit$fit[(total_fit$biomREC == total_fit$Mega_biome)] <- 1


sitesall <- unique(total_fit[c("Latitude","Longitude")])
fits <- matrix(ncol=7,nrow=(nrow(sitesall)))

for (s in c(1:nrow(sitesall))) {

    vec <- total_fit$fit[(total_fit$Latitude == sitesall$Latitude[s] & total_fit$Longitude == sitesall$Longitude[s])]

 timesteps <- total_fit$KaBP[(total_fit$Latitude == sitesall$Latitude[s] & total_fit$Longitude == sitesall$Longitude[s])]


     
    fits[s,2] <- sitesall$Latitude[s] 
    fits[s,1] <- sitesall$Longitude[s]
    fits[s,3] <- length(vec)
    fits[s,4] <- sum(vec)
    fits[s,5] <- sum(vec)/length(vec)
    fits[s,6] <- length(unique(timesteps))
    fits[s,7] <- length(vec)-fits[s,6]

}

fits11 <- fits[fits[,6]>=11,]

write.table (fits[,c(1,2,5)], file="22krun_perfits_new.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (fits[,c(1,2,6)], file="22krun_timesteps_new.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (fits[,c(1,2,4)], file="22krun_fits_new.txt", sep = "\t", row.names=FALSE, col.names=FALSE)
write.table (fits11[,c(1,2,5)], file="22krun_timesteps11_new.txt", sep = "\t", row.names=FALSE, col.names=FALSE)

##


##############################################
#### sitebased-continental mean
####################################

sib_mod <- total[(total$Longitude > 50 & total$Longitude < 180),]
#
sib_modmean <- as.data.frame(time)
sib_recmean <- as.data.frame(time)
sib_modmean$forest <- 0
sib_recmean$forest <- 0
#
nrec$nrasia <- -10


#

for (k in c(1:length(time))) {

    sib_modmean$forest[k] <- (sum(sib_mod$Mega_biome[sib_mod$KaBP == time[k]& sib_mod$Mega_biome==1]))/(nrow(sib_mod[sib_mod$KaBP == time[k],]))

    sib_recmean$forest[k] <- (sum(sib_mod$biomREC[sib_mod$KaBP == time[k]& sib_mod$biomREC==1]))/(nrow(sib_mod[sib_mod$KaBP == time[k],]))

nrec$nrasia[k] <- nrow(sib_mod[sib_mod$KaBP == time[k],])

}
-----------------
eur_mod <- total[(total$Longitude >= -10 & total$Longitude <= 50),]
#
eur_modmean <- as.data.frame(time)
eur_recmean <- as.data.frame(time)
eur_modmean$forest <- 0
eur_recmean$forest <- 0

nrec$nreuro <- -10
#
#

for (k in c(1:length(time))) {

    eur_modmean$forest[k] <- (sum(eur_mod$Mega_biome[eur_mod$KaBP == time[k]& eur_mod$Mega_biome==1]))/(nrow(eur_mod[eur_mod$KaBP == time[k],]))

    eur_recmean$forest[k] <- (sum(eur_mod$biomREC[eur_mod$KaBP == time[k]& eur_mod$biomREC==1]))/(nrow(eur_mod[eur_mod$KaBP == time[k],]))


nrec$nreuro[k] <- nrow(eur_mod[eur_mod$KaBP == time[k],])

}

###############
nam_mod <- total[(total$Longitude >= -180 & total$Longitude <= -47),]
#
nam_modmean <- as.data.frame(time)
nam_recmean <- as.data.frame(time)
nam_modmean$forest <- 0
nam_recmean$forest <- 0

nrec$nrnam <- -10
#
#

for (k in c(1:length(time))) {

    nam_modmean$forest[k] <- (sum(nam_mod$Mega_biome[nam_mod$KaBP == time[k]& nam_mod$Mega_biome==1]))/(nrow(nam_mod[nam_mod$KaBP == time[k],]))

    nam_recmean$forest[k] <- (sum(nam_mod$biomREC[nam_mod$KaBP == time[k]& nam_mod$biomREC==1]))/(nrow(nam_mod[nam_mod$KaBP == time[k],]))


nrec$nrnam[k] <- nrow(nam_mod[nam_mod$KaBP == time[k],])

}


######################################################################
# plot number of records (Supp. Fig.2)
#############

s <- rgb(213, 94, 0, max=255)

pdf("25krun_number_records.pdf")

par(mfrow=c(1,1))
par(mar = c(12, 5, 8, 4))

plot(-nrec$time*1000, nrec$nr, type = "l", col = "black", xlab = "years BP", ylim = c(0.0, 1000), ylab = "number of sites [%] ", main = "", pch = 19, yaxt="n", lwd=2.5, cex.lab=1.2, cex.axis = 1.2, cex = 0.5, )


ytick<-seq(0.0, 1000.0, by=200)
axis(side=2, at=ytick, las=1, cex.axis=1.2)
abline(h=seq(0,1000,100), lty=3, col="darkgrey")

abline(v=c(-24250,-11050), lty=2, col=s)
abline(v=c(-22000, -7000), lty=4, col="blue")

lines(-nrec$time*1000, nrec$nrasia, lwd=2.5, col="red")

lines(-nrec$time*1000, nrec$nreuro, lwd=2.5, col="blue")

lines(-nrec$time*1000, nrec$nrnam, lwd=2.5, col="orange")


legend("topleft", inset=.09, legend=c("total", "Asia", "Europe", "N America"), col=c("black", "red", "blue", "orange"), lwd=3, cex=1.2, lty=1,  xpd=NA, bg='white',y.intersp=0.92,x.intersp=0.92)

dev.off()
###########
############################
