# script to compare moisture maximum in East Asia between pollen-based reconstructions and non-pollen based reconstructions.
# plots Figure Suppl. Fig 4
# the dataset used here is restricted and can be obtained by contacting Yongbo Wang


library(matrixStats)
library(irr)

# read in table fo pollen-based reconstructions
moist <- read.table("moisture_invert_pollen_2021.txt", header=FALSE)

asia_GC <- as.data.frame(stack(as.vector(moist[2,])))

colnames(asia_GC) <- c("longitude","ind")

asia_GC <- cbind(asia_GC$longitude,stack(as.vector(moist[1,])))
colnames(asia_GC) <- c("longitude","latitude","ind")

asia_GC <- na.omit(asia_GC[,1:2])

asia_GC$max <- -99

#########
# read in table with times
trec <- read.table("moisture_rec_times.txt", header=FALSE)
trec <- trec*-1000c
for (k in c(1:51)) {
s=k+1
vector <- moist[3:153,s]
max <- which.max(vector)
asia_GC$max[k] <- trec[max,]
}

write.table (asia_GC, file="moisture_max_all_poll.txt", sep = "\t", row.names=FALSE, col.names=FALSE)


#############################

poll_count <- trec

for (t in c(1:151)) {
s=t+2
vec <- as.vector(moist[s,2:52])
poll_count$we2[t] <- length(which(vec==2))/length(which(vec<10))
poll_count$we1[t] <- length(which(vec==1))/length(which(vec<10))
poll_count$we0[t] <- length(which(vec==0))/length(which(vec<10))
poll_count$dry[t] <- length(which(vec<0))/length(which(vec<10))
poll_count$rec[t] <- sum(poll_count[t,2:5])
}

#plotting
pdf("moisture_recons_pollen_per.pdf")
ggplot(poll_count, aes(x=V1)) + 
  geom_area(aes(y=we2+we1+we0+dry, fill="dry")) + 
  geom_area(aes(y=we1+we2+we0, fill="we0")) +
  geom_area(aes(y=we2+we1, fill="we1")) +
  geom_area(aes(y=we2, fill="we2")) +
  labs(title="pollen-based moisture reconstructions", 
       y="percent of records", x="years BP") +  # title and caption
  scale_fill_manual(name="", 
                    values = c("dry"="yellow","we2"="darkblue", "we1"="lightblue","we0"="grey")) +
		    geom_hline(yintercept=0.25,linetype="dashed",color="red") +
		    geom_hline(yintercept=0.50,linetype="dashed",color="red") +
		    geom_hline(yintercept=0.75,linetype="dashed",color="red")		    



dev.off()
############
# read in table for non-pollen based reconstructions

moist <- read.table("moisture_Asia_all_nonpoll.csv", header=FALSE)
npoll_count <- trec

for (t in c(1:151)) {
s=t+2
vec <- as.vector(moist[s,2:84])
npoll_count$we2[t] <- length(which(vec==2))/length(which(vec<10))
npoll_count$we1[t] <- length(which(vec==1))/length(which(vec<10))
npoll_count$we0[t] <- length(which(vec==0))/length(which(vec<10))
npoll_count$dry[t] <- length(which(vec<0))/length(which(vec<10))
npoll_count$rec[t] <- sum(npoll_count[t,2:5])
}

#### plot
pdf("moisture_recons_nonpollen_perc.pdf")
ggplot(npoll_count, aes(x=V1)) + 
  geom_area(aes(y=we2+we1+we0+dry, fill="dry")) + 
  geom_area(aes(y=we1+we2+we0, fill="we0")) +
  geom_area(aes(y=we2+we1, fill="we1")) +
  geom_area(aes(y=we2, fill="we2")) +
  labs(title="non-pollen-based moisture reconstructions", 
       y="percent of records", x="years BP") +  # title and caption
  scale_fill_manual(name="", 
                    values = c("dry"="yellow","we2"="darkblue", "we1"="lightblue","we0"="grey")) +
		    geom_hline(yintercept=0.25,linetype="dashed",color="red") +
		    geom_hline(yintercept=0.50,linetype="dashed",color="red") +
		    geom_hline(yintercept=0.75,linetype="dashed",color="red")		    


dev.off()
