# script for calculating the minimum in openess (= maximum in forest similarity)
# input, model: MPI-ESM_openess.nc
# input reconstructions: Asia_forratio.csv, Europe_forratio.csv, Nam_forratio.csv
# output dataset needed for plotting Fig.3

library(ncdf4)
library(irr)


# read in model data
########################
mfor <- nc_open("JSBACH_pmt_opensub2.nc")
openmod <- ncvar_get(mfor, "cover_fract")
latc <- ncvar_get(mfor, "lat")
lonc <- ncvar_get(mfor, "lon")
londf <- as.data.frame(as.matrix(lonc))
latdf <- as.data.frame(as.matrix(latc))
londf$V1[londf$V1 >= 181] <- (londf$V1[londf$V1 >= 181] - 360)
t <- seq(-24950,-50,100)


#############################

maximum <- matrix(0,nrow=dim(lonc), ncol=dim(latc))


for (i in 1:dim(lonc)) {

for (j in 1:dim(latc)) {

p <- which.max(openmod[i,j,])

q <- sum(openmod[i,j,])
print(c(i,j,p,t[p]))

maximum[i,j] <- t[p]

if (openmod[i,j,240] == -99999) {
maximum[i,j] <- 100
}
}
}

# define dimensions
#tunits2 <- tunit
londim <- ncdim_def("lon","degrees_east",as.double(lonc)) 
latdim <- ncdim_def("lat","degrees_north",as.double(latc)) 

# define variables
fillvalue <- -9999
dlname <- "tree_cover_max"
m_def <- ncvar_def("tree_max","",list(londim,latdim),fillvalue,dlname,prec="single")

# create netCDF file and put arrays
ncfname <- "pmt_moc_openess_NH_newsub.nc"
ncout <- nc_create(ncfname,list(m_def),force_v4=T)

# put variables
ncvar_put(ncout,m_def,maximum)


# put additional attributes into dimension and data variables
ncatt_put(ncout,"lon","axis","X") #,verbose=FALSE) #,definemode=FALSE)
ncatt_put(ncout,"lat","axis","Y")

# close the file, writing data to disk
nc_close(ncout)


#read reconstructions
#########
data <- read.table("Asia_forratio.csv", header=TRUE) 
#data <- read.table("Europe_forratio.csv", header=TRUE)
#data <- read.table("Nam_forratio.csv", header=TRUE)


#look for long records and write them in a table
q <- as.data.frame(unique(data[c("Long", "Lat")]))
p <- nrow(q)
cont_rec <- data[1,]*-5

for (i in c(1:p)) {
    site  <- data[(data$Lat == q$Lat[i] & data$Long == q$Long[i]),]
    rownames(site) <- NULL
    tsteps <- site$Age[(site$Age>=2000 & site$Age<=12000)]
    
    
    if (length(tsteps)>=20) {
    print(i)
    print(tsteps)
cont_rec <- rbind(cont_rec,site)
}
}

cont_rec <- cont_rec[2:nrow(cont_rec),]
 rownames(cont_rec) <- NULL
cont_rec$bio <- cont_rec$openess
cont_rec$bio[cont_rec$bio > 1] <- 1
cont_rec$bio[cont_rec$bio < 1] <- 0
cont_rec$Age <- -cont_rec$Age
###########si############

# look for the openess minimum
###################################
s <- as.data.frame(unique(cont_rec[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$max <- 100
tmax$fore <- 100

for (i in c(1:nrow(s))) {
    site  <- cont_rec[(cont_rec$Lat == s$Lat[i] & cont_rec$Long == s$Long[i]),]
    maxtime <- which.max(site$opennorm)
    tmax$max[i] <- -site$Age[maxtime]
    tmax$fore[i] <- site$bio[maxtime]
    }
    

write.table (tmax[,1:3], file="tmax_Asia_cont_subnorm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

#######################
# prepare model data (i.e. bring them in the same format as the reconstructions)
time <- sort(unique(cont_rec$Age))
modelsitet <-  matrix(-1,ncol=6, nrow=1)

for (u in c(1:length(time))) {

    record <- cont_rec[cont_rec$Age == time[u],]
    modelsite <- as.data.frame(cbind(record$Long, record$Lat,record$Age,record$opennorm,record$bio,c(-99999)))   

for (s in c(1:length(t))) {

if (t[s] == time[u]-50) {
    openm <- openmod[,,s]
    print(t[s])
    print(time[u])

for (i in c(1:nrow(record))) {

    londiff <- as.matrix((londf-record$Long[i])^2)             # finds the grid-cell that locates the site
    latdiff <- as.matrix((latdf-record$Lat[i])^2)

    lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
    la <- which.min(latdiff)                     # latitudinal grid-box number of the site-locating grid-box

    modelsite$V6[i] <- openm[lo,la]
    }
    
    }

}
print(modelsite)
modelsitet <- rbind(modelsitet,modelsite)
    
}
##############################################
colnames(modelsitet) <- c("Long","Lat","Age","open_rec","rec_bio","open_mod")
#########
# calculate minimum in openess
#################################
s <- as.data.frame(unique(modelsitet[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$r_max <- 100
tmax$fore <- 100
tmax$m_max <- 100

for (i in c(1:nrow(s))) {
    site  <- modelsitet[(modelsitet$Lat == s$Lat[i] & modelsitet$Long == s$Long[i]),]
    maxtime <- which.max(site$open_rec)
    tmax$r_max[i] <- site$Age[maxtime]
    tmax$fore[i] <- site$rec_bio[maxtime]
    maxtimem <- which.max(site$open_mod)
    tmax$m_max[i] <- site$Age[maxtimem]
    }
    
tmax$diff <- tmax$m_max - tmax$r_max



############## write output needed for Fig.3
write.table (tmax[2:nrow(tmax),1:3], file="tmax_Asia_contr_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,5)], file="tmax_Asia_contm_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,6)], file="tmax_Asia_cont_diff_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

###
###########################
#mean plot
mean <- as.data.frame(time)
mean$rec <- -99
mean$mod <- -99
min <- as.data.frame(time)
min$rec <- -99
min$mod <- -99
max <- as.data.frame(time)
max$rec <- -99
max$mod <- -99


for (u in c(1:length(time))) {

    record <- modelsitet[modelsitet$Age == time[u],]
    record$open_mod[record$open_mod <= -1.5] <- NA
    record <- na.omit(record)
    mean$mod[u] <- mean(record$open_mod)
    mean$rec[u] <- mean(record$open_rec)
    min$mod[u] <- min(record$open_mod)
    min$rec[u] <- min(record$open_rec)
    max$mod[u] <- max(record$open_mod)
    max$rec[u] <- max(record$open_rec)
}


pdf("Asia_mean_openess.pdf")
plot(mean$time[5:40],mean$rec[5:40], type = "l", col = "black", xlab = "Years BP", ylab = "openess", pch = 19, main = "Asia mean openess", ylim = c(-1, 1), yaxt="n", lwd=2.5, cex.lab=1.1, cex = 0.5, )
ytick<-seq(-1, 1, by=0.2)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(h=seq(-1,1,0.2), lty=3, col="darkgrey")
#abline(v=c(-25000,-11000), lty=3, col="darkgrey")

#polygon(x = c(mean$time,rev(mean$time)), y = c(max$rec,rev(max$rec)), col =  adjustcolor("red", alpha.f = 0.20), border=NA)

lines(mean$time,mean$mod, type="l",col="red", lwd=2.5)
lines(mean$time,max$rec, type="l",col="grey", lwd=2.5)

lines(mean$time,max$mod, type="l",col="orange", lwd=2.5)

dev.off()

##################################################################

####################### same for other continents --------------------
----------------------------------------------------------------------
data <- read.table("Europe_forratio.csv", header=TRUE)
#data <- read.table("Nam_forratio.csv", header=TRUE)
data$AgeBP

q <- as.data.frame(unique(data[c("Long", "Lat")]))
p <- nrow(q)
cont_rec <- data[1,]*-5

for (i in c(1:p)) {
    site  <- data[(data$Lat == q$Lat[i] & data$Long == q$Long[i]),]
    rownames(site) <- NULL
    tsteps <- site$Age[(site$Age>=2000 & site$Age<=12000)]
    
    
    if (length(tsteps)>=20) {
    print(i)
    print(tsteps)
cont_rec <- rbind(cont_rec,site)
}
}

cont_rec <- cont_rec[2:nrow(cont_rec),]
 rownames(cont_rec) <- NULL
cont_rec$bio <- cont_rec$openess
cont_rec$bio[cont_rec$bio > 1] <- 1
cont_rec$bio[cont_rec$bio < 1] <- 0
cont_rec$Age <- -cont_rec$Age
###########si############

s <- as.data.frame(unique(cont_rec[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$max <- 100
tmax$fore <- 100

for (i in c(1:nrow(s))) {
    site  <- cont_rec[(cont_rec$Lat == s$Lat[i] & cont_rec$Long == s$Long[i]),]
    maxtime <- which.max(site$opennorm)
    tmax$max[i] <- site$Age[maxtime]
    tmax$fore[i] <- site$bio[maxtime]
    }
    

write.table (tmax[,1:3], file="tmax_Euro_cont_subnorm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

#######################

time <- sort(unique(cont_rec$Age))
modelsitet <-  matrix(-1,ncol=6, nrow=1)

for (u in c(1:length(time))) {

    record <- cont_rec[cont_rec$Age == time[u],]
    modelsite <- as.data.frame(cbind(record$Long, record$Lat,record$Age,record$opennorm,record$bio,c(-99999)))   

for (s in c(1:length(t))) {

if (t[s] == time[u]-50) {
    openm <- openmod[,,s]
    print(t[s])
    print(time[u])

for (i in c(1:nrow(record))) {

    londiff <- as.matrix((londf-record$Long[i])^2)             # finds the grid-cell that locates the site
    latdiff <- as.matrix((latdf-record$Lat[i])^2)

    lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
    la <- which.min(latdiff)                     # latitudinal grid-box number of the site-locating grid-box

    modelsite$V6[i] <- openm[lo,la]
    }
    
    }

}
print(modelsite)
modelsitet <- rbind(modelsitet,modelsite)
    
}
##############################################
colnames(modelsitet) <- c("Long","Lat","Age","open_rec","rec_bio","open_mod")
s <- as.data.frame(unique(modelsitet[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$r_max <- 100
tmax$fore <- 100
tmax$m_max <- 100

for (i in c(1:nrow(s))) {
    site  <- modelsitet[(modelsitet$Lat == s$Lat[i] & modelsitet$Long == s$Long[i]),]
    maxtime <- which.max(site$open_rec)
    tmax$r_max[i] <- site$Age[maxtime]
    tmax$fore[i] <- site$rec_bio[maxtime]
    maxtimem <- which.max(site$open_mod)
    tmax$m_max[i] <- site$Age[maxtimem]
    }
    
tmax$diff <- tmax$m_max - tmax$r_max

write.table (tmax[2:nrow(tmax),1:3], file="tmax_Euro_contr_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,5)], file="tmax_Euro_contm_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,6)], file="tmax_Euro_cont_diff_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

###
###########################
#mean plot
mean <- as.data.frame(time)
mean$rec <- -99
mean$mod <- -99
min <- as.data.frame(time)
min$rec <- -99
min$mod <- -99
max <- as.data.frame(time)
max$rec <- -99
max$mod <- -99


for (u in c(1:length(time))) {

    record <- modelsitet[modelsitet$Age == time[u],]
    record$open_mod[record$open_mod <= -1.5] <- NA
    record <- na.omit(record)
    mean$mod[u] <- mean(record$open_mod)
    mean$rec[u] <- mean(record$open_rec)
    min$mod[u] <- min(record$open_mod)
    min$rec[u] <- min(record$open_rec)
    max$mod[u] <- max(record$open_mod)
    max$rec[u] <- max(record$open_rec)
}


pdf("Euro_mean_openess.pdf")
plot(mean$time[5:40],mean$rec[5:40], type = "l", col = "black", xlab = "Years BP", ylab = "openess", pch = 19, main = "Euro mean openess", ylim = c(-1, 1), yaxt="n", lwd=2.5, cex.lab=1.1, cex = 0.5, )
ytick<-seq(-1, 1, by=0.2)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(h=seq(-1,1,0.2), lty=3, col="darkgrey")
#abline(v=c(-25000,-11000), lty=3, col="darkgrey")

#polygon(x = c(mean$time,rev(mean$time)), y = c(max$rec,rev(max$rec)), col =  adjustcolor("red", alpha.f = 0.20), border=NA)

lines(mean$time,mean$mod, type="l",col="red", lwd=2.5)
lines(mean$time,max$rec, type="l",col="grey", lwd=2.5)

lines(mean$time,max$mod, type="l",col="orange", lwd=2.5)

dev.off()

##################################################################
data <- read.table("Nam_forratio.csv", header=TRUE)
data$AgeBP

q <- as.data.frame(unique(data[c("Long", "Lat")]))
p <- nrow(q)
cont_rec <- data[1,]*-5

for (i in c(1:p)) {
    site  <- data[(data$Lat == q$Lat[i] & data$Long == q$Long[i]),]
    rownames(site) <- NULL
    tsteps <- site$Age[(site$Age>=2000 & site$Age<=12000)]
    
    
    if (length(tsteps)>=20) {
    print(i)
    print(tsteps)
cont_rec <- rbind(cont_rec,site)
}
}

cont_rec <- cont_rec[2:nrow(cont_rec),]
 rownames(cont_rec) <- NULL
cont_rec$bio <- cont_rec$openess
cont_rec$bio[cont_rec$bio > 1] <- 1
cont_rec$bio[cont_rec$bio < 1] <- 0
cont_rec$Age <- -cont_rec$Age
###########si############

s <- as.data.frame(unique(cont_rec[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$max <- 100
tmax$fore <- 100

for (i in c(1:nrow(s))) {
    site  <- cont_rec[(cont_rec$Lat == s$Lat[i] & cont_rec$Long == s$Long[i]),]
    maxtime <- which.max(site$opennorm)
    tmax$max[i] <- site$Age[maxtime]
    tmax$fore[i] <- site$bio[maxtime]
    }
    

write.table (tmax[,1:3], file="tmax_Nam_cont_subnorm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

#######################

time <- sort(unique(cont_rec$Age))
modelsitet <-  matrix(-1,ncol=6, nrow=1)

for (u in c(1:length(time))) {

    record <- cont_rec[cont_rec$Age == time[u],]
    modelsite <- as.data.frame(cbind(record$Long, record$Lat,record$Age,record$opennorm,record$bio,c(-99999)))   

for (s in c(1:length(t))) {

if (t[s] == time[u]-50) {
    openm <- openmod[,,s]
    print(t[s])
    print(time[u])

for (i in c(1:nrow(record))) {

    londiff <- as.matrix((londf-record$Long[i])^2)             # finds the grid-cell that locates the site
    latdiff <- as.matrix((latdf-record$Lat[i])^2)

    lo <- which.min(londiff)                     # longitudinal grid-box number of the site-locating grid-box
    la <- which.min(latdiff)                     # latitudinal grid-box number of the site-locating grid-box

    modelsite$V6[i] <- openm[lo,la]
    }
    
    }

}
print(modelsite)
modelsitet <- rbind(modelsitet,modelsite)
    
}
##############################################
colnames(modelsitet) <- c("Long","Lat","Age","open_rec","rec_bio","open_mod")
s <- as.data.frame(unique(modelsitet[c("Long", "Lat")]))
tmax <- as.data.frame(s)
tmax$r_max <- 100
tmax$fore <- 100
tmax$m_max <- 100

for (i in c(1:nrow(s))) {
    site  <- modelsitet[(modelsitet$Lat == s$Lat[i] & modelsitet$Long == s$Long[i]),]
    maxtime <- which.max(site$open_rec)
    tmax$r_max[i] <- site$Age[maxtime]
    tmax$fore[i] <- site$rec_bio[maxtime]
    maxtimem <- which.max(site$open_mod)
    tmax$m_max[i] <- site$Age[maxtimem]
    }
    
tmax$diff <- tmax$m_max - tmax$r_max

write.table (tmax[2:nrow(tmax),1:3], file="tmax_Nam_contr_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,5)], file="tmax_Nam_contm_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

write.table (tmax[2:nrow(tmax),c(1,2,6)], file="tmax_Nam_cont_diff_norm.csv", sep = "\t", row.names=FALSE, col.names=FALSE)

###
###########################
#mean plot
mean <- as.data.frame(time)
mean$rec <- -99
mean$mod <- -99
min <- as.data.frame(time)
min$rec <- -99
min$mod <- -99
max <- as.data.frame(time)
max$rec <- -99
max$mod <- -99


for (u in c(1:length(time))) {

    record <- modelsitet[modelsitet$Age == time[u],]
    record$open_mod[record$open_mod <= -1.5] <- NA
    record <- na.omit(record)
    mean$mod[u] <- mean(record$open_mod)
    mean$rec[u] <- mean(record$open_rec)
    min$mod[u] <- min(record$open_mod)
    min$rec[u] <- min(record$open_rec)
    max$mod[u] <- max(record$open_mod)
    max$rec[u] <- max(record$open_rec)
}


pdf("Nam_mean_openess.pdf")
plot(mean$time[5:40],mean$rec[5:40], type = "l", col = "black", xlab = "Years BP", ylab = "openess", pch = 19, main = "Nam mean openess", ylim = c(-1, 1), yaxt="n", lwd=2.5, cex.lab=1.1, cex = 0.5, )
ytick<-seq(-1, 1, by=0.2)
axis(side=2, at=ytick, las=1, cex.axis=1.1)
abline(h=seq(-1,1,0.2), lty=3, col="darkgrey")
#abline(v=c(-25000,-11000), lty=3, col="darkgrey")

#polygon(x = c(mean$time,rev(mean$time)), y = c(max$rec,rev(max$rec)), col =  adjustcolor("red", alpha.f = 0.20), border=NA)

lines(mean$time,mean$mod, type="l",col="red", lwd=2.5)
lines(mean$time,max$rec, type="l",col="grey", lwd=2.5)

lines(mean$time,max$mod, type="l",col="orange", lwd=2.5)

dev.off()

##################################################################